==> bayonne2-2.0.0.tar.gz: bayonne2-2.0.0/modules/tcpmon/service.cpp <==
// Copyright (C) 2005 Open Source Telecom Corporation.
//  
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software 
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#include "module.h"
#include <cc++/process.h>

namespace moduleTCP {
using namespace ost;
using namespace std;

Service Service::tcp;
bool Service::active = false;

Service::Service() :
BayonneService(0, 0), Keydata("/bayonne/module/tcpmon")
{
	static Keydata::Define defkeys[] = {
	{"interface", "127.0.0.1"},
	{"port", "5555"},
	{"secret", "pass"},
	{NULL, NULL}};

	if(Bayonne::getUserdata())
	        load("~bayonne/tcpmon");

	load(defkeys);
#ifdef	WIN32
	loadFile("C:\\Program Files\\GNU Telephony\\Bayonne Config\\module.ini", "tcpmon");
#endif

}

void Service::stopService(void)
{
	active = false;
	terminate();
}

void Service::run(void)
{
	InetAddress addr(getLast("interface"));
	tpport_t port = atoi(getLast("port"));
	TCPSocket tcp(addr, port);
	Session *session;

	active = true;
	slog.debug("tcpmon service started");

	for(;;)
	{
                if(tcp.isPendingConnection(30))
                {
                        session = new Session(tcp);
                        session->detach();
                }
		Thread::yield();
	}

	Thread::sync();
}

} // namespace

==> bayonne2-2.1.1.tar.gz: bayonne2-2.1.1/modules/tcpmon/service.cpp <==
// Copyright (C) 2005 Open Source Telecom Corporation.
//  
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software 
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#include "module.h"
#include <cc++/process.h>

namespace moduleTCP {
using namespace ost;
using namespace std;

Service Service::tcp;
bool Service::active = false;

Service::Service() :
BayonneService(0, 0), 
BayonneZeroconf("_tcpmon._tcp", ZEROCONF_IPV4),
Keydata("/bayonne/module/tcpmon")
{
	static Keydata::Define defkeys[] = {
	{"interface", "127.0.0.1"},
	{"port", "5555"},
	{"secret", "pass"},
	{"zeroconf", "yes"},
	{NULL, NULL}};

	const char *cp;

	if(Bayonne::getUserdata())
	        load("~bayonne/tcpmon");

	load(defkeys);
#ifdef	WIN32
	loadFile("C:\\Program Files\\GNU Telephony\\Bayonne Config\\module.ini", "tcpmon");
#endif

	cp = getLast("zeroconf");
	switch(*cp)
	{
	case 'y':
	case 'Y':
	case 't':
	case 'T':
	case '1':
		zeroconf_port = atoi(getLast("port"));	
	}
}

void Service::stopService(void)
{
	active = false;
	terminate();
}

void Service::run(void)
{
	InetAddress addr(getLast("interface"));
	tpport_t port = atoi(getLast("port"));
	TCPSocket tcp(addr, port);
	Session *session;

	active = true;
	slog.debug("tcpmon service started");

	for(;;)
	{
                if(tcp.isPendingConnection(30))
                {
                        session = new Session(tcp);
                        session->detach();
                }
		Thread::yield();
	}

	Thread::sync();
}

} // namespace
